@@ -1,6 +1,6 @@
 package Statocles::App;
 # ABSTRACT: Base role for Statocles applications
-$Statocles::App::VERSION = '0.046';
+$Statocles::App::VERSION = '0.047';
 use Statocles::Base 'Role';
 use Statocles::Link;
 requires 'pages';
@@ -33,8 +33,17 @@ around pages => sub {
     # Add the url_root
     my $url_root = $self->url_root;
     for my $page ( @pages ) {
-        next if $page->path =~ /^$url_root/;
-        $page->path( join "/", $url_root, $page->path );
+        my @url_attrs = qw( path );
+
+        if ( $page->isa( 'Statocles::Page::List' ) ) {
+            push @url_attrs, qw( next prev );
+        }
+
+        for my $attr ( @url_attrs ) {
+            if ( $page->$attr && $page->$attr !~ /^$url_root/ ) {
+                $page->$attr( join "/", $url_root, $page->$attr );
+            }
+        }
     }
 
     return @pages;
@@ -69,7 +78,7 @@ Statocles::App - Base role for Statocles applications
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 DESCRIPTION
 
