@@ -1,6 +1,6 @@
 package Statocles::App::Blog;
 # ABSTRACT: A blog application
-$Statocles::App::Blog::VERSION = '0.046';
+$Statocles::App::Blog::VERSION = '0.047';
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store::File;
@@ -284,8 +284,8 @@ sub index {
 
     my @pages = Statocles::Page::List->paginate(
         after => $self->page_size,
-        path => 'page/%i/index.html',
-        index => 'index.html',
+        path => '/page/%i/index.html',
+        index => '/index.html',
         # Sorting by path just happens to also sort by date
         pages => [ sort { $b->path cmp $a->path } @index_post_pages ],
         app => $self,
@@ -332,8 +332,8 @@ sub tag_pages {
     for my $tag ( keys %tagged_docs ) {
         my @tag_pages = Statocles::Page::List->paginate(
             after => $self->page_size,
-            path => join( "/", 'tag', $self->_tag_url( $tag ), 'page/%i/index.html' ),
-            index => join( "/", 'tag', $self->_tag_url( $tag ), 'index.html' ),
+            path => join( "/", '', 'tag', $self->_tag_url( $tag ), 'page/%i/index.html' ),
+            index => join( "/", '', 'tag', $self->_tag_url( $tag ), 'index.html' ),
             # Sorting by path just happens to also sort by date
             pages => [ sort { $b->path cmp $a->path } @{ $tagged_docs{ $tag } } ],
             app => $self,
@@ -460,7 +460,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 DESCRIPTION
 
