@@ -1,10 +1,9 @@
 package Statocles::App::Perldoc;
 # ABSTRACT: Render documentation for Perl modules
-$Statocles::App::Perldoc::VERSION = '0.046';
+$Statocles::App::Perldoc::VERSION = '0.047';
 use Statocles::Base 'Class';
 use Statocles::Page::Plain;
 use Scalar::Util qw( blessed );
-use List::MoreUtils qw( any );
 use Pod::Simple::Search;
 use Pod::Simple::XHTML;
 with 'Statocles::App';
@@ -232,7 +231,7 @@ sub _weave_module {
     my $finder = sub {
         my $node = $_[ 1 ];
         return 0
-            unless any { $node->isa( $_ ) }
+            unless grep { $node->isa( $_ ) }
         qw( PPI::Token::Quote PPI::Token::QuoteLike PPI::Token::HereDoc );
         return 1 if $node->content =~ /^=[a-z]/m;
         return 0;
@@ -276,7 +275,7 @@ Statocles::App::Perldoc - Render documentation for Perl modules
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 DESCRIPTION
 
