@@ -1,6 +1,6 @@
 package Statocles::Base;
 # ABSTRACT: Base module for Statocles modules
-$Statocles::Base::VERSION = '0.046';
+$Statocles::Base::VERSION = '0.047';
 use strict;
 use warnings;
 use base 'Import::Base';
@@ -53,7 +53,7 @@ our %IMPORT_BUNDLES = (
         'Statocles::Event',
         sub {
             my ( $bundles, $args ) = @_;
-            Moo::Role->apply_role_to_package( $args->{package}, 'Beam::Emitter' );
+            Moo::Role->apply_roles_to_package( $args->{package}, 'Beam::Emitter' );
             return;
         },
     ],
@@ -71,7 +71,7 @@ Statocles::Base - Base module for Statocles modules
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 SYNOPSIS
 
