@@ -1,6 +1,6 @@
 package Statocles::Document;
 # ABSTRACT: Base class for all Statocles documents
-$Statocles::Document::VERSION = '0.046';
+$Statocles::Document::VERSION = '0.047';
 use Statocles::Base 'Class';
 
 
@@ -79,6 +79,11 @@ has layout => (
     predicate => 'has_layout',
 );
 
+
+has data => (
+    is => 'rw',
+);
+
 1;
 
 __END__
@@ -91,7 +96,7 @@ Statocles::Document - Base class for all Statocles documents
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 DESCRIPTION
 
@@ -158,6 +163,11 @@ A layout template override for this document. If set, the L<document
 page|Statocles::Page::Document> will use this instead of the layout provided
 by the application.
 
+=head2 data
+
+Any kind of miscellaneous data. This is available immediately in the document
+content.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
