@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::Document::VERSION = '0.046';
+$Statocles::Page::Document::VERSION = '0.047';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Statocles::Template;
@@ -55,7 +55,7 @@ sub content {
     my ( $self, %vars ) = @_;
     my $content = $self->document->content;
     my $tmpl = $self->site->theme->build_template( $self->path, $content );
-    my $rendered = $tmpl->render( %vars, $self->vars );
+    my $rendered = $tmpl->render( %vars, $self->vars, self => $self->document );
     return $self->markdown->markdown( $rendered );
 }
 
@@ -110,7 +110,7 @@ Statocles::Page::Document - Render documents into HTML
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 DESCRIPTION
 
