@@ -1,10 +1,9 @@
 package Statocles::Page::List;
 # ABSTRACT: A page presenting a list of other pages
-$Statocles::Page::List::VERSION = '0.046';
+$Statocles::Page::List::VERSION = '0.047';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use List::Util qw( max );
-use List::MoreUtils qw( part );
 use Statocles::Template;
 
 
@@ -15,7 +14,7 @@ has pages => (
 
 
 has [qw( next prev )] => (
-    is => 'ro',
+    is => 'rw',
     isa => Path,
     coerce => Path->coercion,
 );
@@ -49,7 +48,11 @@ sub paginate {
     my $path_format = delete $args{path};
     my $index = delete $args{index};
 
-    my @sets = part { int( $_ / $after ) } 0..$#{$pages};
+    my @sets;
+    for my $i ( 0..$#{$pages} ) {
+        push @{ $sets[ int( $i / $after ) ] }, $pages->[ $i ];
+    }
+
     my @retval;
     for my $i ( 0..$#sets ) {
         my $path = $index && $i == 0 ? $index : sprintf( $path_format, $i + 1 );
@@ -61,7 +64,7 @@ sub paginate {
 
         push @retval, $class->new(
             path => $path,
-            pages => [ @{$pages}[ @{ $sets[$i] } ] ],
+            pages => $sets[$i],
             ( $next ? ( next => $next ) : () ),
             ( $i > 0 ? ( prev => $prev ) : () ),
             date => $pages->[0]->date,
@@ -92,7 +95,7 @@ Statocles::Page::List - A page presenting a list of other pages
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 DESCRIPTION
 
