@@ -1,12 +1,11 @@
 package Statocles::Store::File;
 # ABSTRACT: A store made up of plain files
-$Statocles::Store::File::VERSION = '0.046';
+$Statocles::Store::File::VERSION = '0.047';
 use Statocles::Base 'Class';
 with 'Statocles::Store';
 use Scalar::Util qw( weaken blessed );
 use Statocles::Document;
 use YAML;
-use List::MoreUtils qw( firstidx );
 use File::Spec::Functions qw( splitdir );
 
 my $DATETIME_FORMAT = '%Y-%m-%d %H:%M:%S';
@@ -113,10 +112,10 @@ sub parse_frontmatter {
         shift @lines;
 
         # The next --- is the end of the YAML frontmatter
-        my $i = firstidx { /^---/ } @lines;
+        my ( $i ) = grep { $lines[ $_ ] =~ /^---/ } 0..$#lines;
 
         # If we did not find the marker between YAML and Markdown
-        if ( $i < 0 ) {
+        if ( !defined $i ) {
             die "Could not find end of front matter (---) in '$from'\n";
         }
 
@@ -259,7 +258,7 @@ Statocles::Store::File - A store made up of plain files
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 DESCRIPTION
 
