@@ -1,11 +1,11 @@
 package Statocles::Test;
 # ABSTRACT: Common test routines for Statocles
-$Statocles::Test::VERSION = '0.046';
+$Statocles::Test::VERSION = '0.047';
 use Statocles::Base;
 use Test::More;
 use Test::Exception;
 use Test::Deep;
-use File::Copy::Recursive qw( dircopy );
+use Statocles::Util qw( dircopy );
 
 use base qw( Exporter );
 our @EXPORT_OK = qw(
@@ -188,8 +188,8 @@ sub build_temp_site {
     my ( $share_dir ) = @_;
 
     my $tmp = Path::Tiny->tempdir;
-    dircopy $share_dir->child( qw( app blog ) )->stringify, $tmp->child( 'blog' )->stringify;
-    dircopy $share_dir->child( 'theme' )->stringify, $tmp->child( 'theme' )->stringify;
+    dircopy $share_dir->child( qw( app blog ) ), $tmp->child( 'blog' );
+    dircopy $share_dir->child( 'theme' ), $tmp->child( 'theme' );
     $tmp->child( 'build_site' )->mkpath;
     $tmp->child( 'deploy_site' )->mkpath;
     $tmp->child( 'build_foo' )->mkpath;
@@ -305,7 +305,7 @@ Statocles::Test - Common test routines for Statocles
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 DESCRIPTION
 
